@@ -113,7 +113,9 @@ bool KWQTableView::doHtmlExport(const QUrl &url)
     QTextDocument td;
     td.setMetaInformation(QTextDocument::DocumentTitle, model()->sourceModel()->document()->title());
     QTextStream out(&data);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     out.setCodec("utf-8");
+#endif
     createPages(&printer, &td, false);
     out << td.toHtml("utf-8");
     data.close();
@@ -748,7 +750,7 @@ void KWQTableView::doVocabSound()
 {
   QUrl currentUrl(model()->data(currentIndex(), KWQTableModel::SoundRole).toString());
 
-  QUrl soundUrl = QFileDialog::getOpenFileUrl(this, i18n("Select Sound"), currentUrl, i18n("All Files (*)"));
+  QUrl soundUrl = QFileDialog::getOpenFileUrl(this, i18nc("@title:window", "Select Sound"), currentUrl, i18n("All Files (*)"));
   if (!soundUrl.isEmpty()) {
     KWQCommandSound *kwqc = new KWQCommandSound(this, soundUrl);
     m_undoStack->push(kwqc);
